==> dl.php?src=linea21_2_7_0.zip: linea21/languages/es/lang_home.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Inicio";
$lang['home']['comment']="%s últimos comentarios";
$lang['home']['comment_to_moderate']="%s comentario (s) en espera de validación";
$lang['home']['project']="Proyectos con fecha estimada de finalización cercana";
$lang['home']['my-projects']="My projects"; // @todo translation
$lang['home']['project_task']="Tasks to operate"; // @todo translation
$lang['home']['into_project']="into project : "; // @todo translation
$lang['home']['workshop_pending_users']="grupos de trabajo : %s usuario(s) en espera";
$lang['home']['latest_connected_users']="%s usuarios conectados en los últimos 15 minutos";
$lang['home']['yp']="organización(es) actualmente en espera para registrarse";
$lang['home']['dashboard']="indicador(es) para actualizar";
$lang['home']['user']="usuario(s) registrados desde la última sesión";
$lang['home']['news']="Últimas 3 noticias";
$lang['home']['publi']="Última publicación";
$lang['home']['report']="Últimos informes publicados por los grupos de trabajo";
$lang['home']['accueil']="Bienvenido a la consola de administracion de Linea21.";

$lang['home']['noresult']="No existen valores publicados en este módulo";
$lang['home']['noupdate']="No existen valores actualizados en este módulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Para acceder a un módulo haga clic en su nombre, en el menú situado a la izquierda.";
$lang['home']['help_list2']="Puede realizar búsquedas utilizando el input del campo 'buscar'.";
$lang['home']['help_list3']="Para buscar dentro de un módulo, entre en el módulo y haga clic en el 'buscar'.";
$lang['home']['help_list4']="No dude en utilizar las ayudas específicas de cada módulo.";
?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/es/lang_home.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Inicio";
$lang['home']['comment']="%s últimos comentarios";
$lang['home']['comment_to_moderate']="%s comentario (s) en espera de validación";
$lang['home']['project']="Proyectos con fecha estimada de finalización cercana";
$lang['home']['my-projects']="My projects"; // @todo translation
$lang['home']['project_task']="Tasks to operate"; // @todo translation
$lang['home']['into_project']="into project : "; // @todo translation
$lang['home']['workshop_pending_users']="grupos de trabajo : %s usuario(s) en espera";
$lang['home']['latest_connected_users']="%s usuarios conectados en los últimos 15 minutos";
$lang['home']['yp']="organización(es) actualmente en espera para registrarse";
$lang['home']['dashboard']="indicador(es) para actualizar";
$lang['home']['indicator-last-value']="last value entered on %s"; // @todo translation
$lang['home']['indicator-delayed-msg']="estimated delay of %s day(s)"; // @todo translation
$lang['home']['indicator-next-entry']="next entry in %s day(s)"; // @todo translation
$lang['home']['indicator-up-to-date']="up-to-date"; // @todo translation
$lang['home']['indicator-delayed']="delayed"; // @todo translation
$lang['home']['user']="usuario(s) registrados desde la última sesión";
$lang['home']['news']="Últimas 3 noticias";
$lang['home']['publi']="Última publicación";
$lang['home']['report']="Últimos informes publicados por los grupos de trabajo";
$lang['home']['accueil']="Bienvenido a la consola de administracion de Linea21.";

$lang['home']['noresult']="No existen valores publicados en este módulo";
$lang['home']['noupdate']="No existen valores actualizados en este módulo";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Para acceder a un módulo haga clic en su nombre, en el menú situado a la izquierda.";
$lang['home']['help_list2']="Puede realizar búsquedas utilizando el input del campo 'buscar'.";
$lang['home']['help_list3']="Para buscar dentro de un módulo, entre en el módulo y haga clic en el 'buscar'.";
$lang['home']['help_list4']="No dude en utilizar las ayudas específicas de cada módulo.";
?>
